==> report-0.0.1.tar.gz: tool/backup/main.dart <==
// Copyright (c) 2016, the Dart project authors. Please see the AUTHORS file
// for details. All rights reserved. Use of this source code is governed by a
// BSD-style license that can be found in the LICENSE.md file.

import 'dart:convert';

import 'package:_fe_analyzer_shared/src/scanner/token.dart';
import 'package:_fe_analyzer_shared/src/scanner/io.dart' show readBytesFromFileSync;
import 'package:_fe_analyzer_shared/src/scanner/error_token.dart';
import 'package:_fe_analyzer_shared/src/scanner/scanner.dart';
import 'dart:convert' show LineSplitter, utf8;

import 'dart:io' show File;

import 'package:_fe_analyzer_shared/src/scanner/token.dart' show Token;

import 'package:_fe_analyzer_shared/src/scanner/io.dart' show readBytesFromFileSync;

import 'package:_fe_analyzer_shared/src/scanner/scanner.dart' show scan;

import 'package:_fe_analyzer_shared/src/parser/listener.dart' show Listener;

import 'package:_fe_analyzer_shared/src/parser/parser.dart';

import 'package:_fe_analyzer_shared/src/parser/identifier_context.dart' show IdentifierContext;

void main() {
  List<int> bytes = utf8.encode('class A { }').toList();
  bytes.add(0);
  mainEntryPoint(['/Users/dansun/Documents/github/report/package/bloc/test1/lib/test1.dart']);
  // scanAll({Uri.directory('/Users/dansun/Documents/github/report/tool'): bytes});
}

// scanAll(Map<Uri, List<int>> files, {bool verbose: true, bool verify: true}) {
//   Stopwatch sw = new Stopwatch()..start();
//   int byteCount = 0;
//   files.forEach((Uri uri, List<int> bytes) {
//     Token token = scan(bytes).tokens;
//     if (verbose) printTokens(token);
//     if (verify) verifyErrorTokens(token, uri);
//     byteCount += bytes.length - 1;
//   });
//   sw.stop();
//   print("Scanning files took: ${sw.elapsed}");
//   print("Bytes/ms: ${byteCount / sw.elapsedMilliseconds}");
// }
//
// void printTokens(Token token) {
//   while (!token.isEof) {
//     print("${token.charOffset}: $token");
//     token = token.next;
//   }
// }
//
// /// Verify that the fasta scanner recovery has moved all of the ErrorTokens
// /// to the beginning of the stream. If an out-of-order ErrorToken is
// /// found, then print some diagnostic information and throw an exception.
// void verifyErrorTokens(Token firstToken, Uri uri) {
//   Token token = firstToken;
//   while (token is ErrorToken) {
//     token = token.next;
//   }
//
//   while (!token.isEof) {
//     if (token is ErrorToken) {
//       print('Found out-of-order ErrorTokens when scanning:\n  $uri');
//
//       // Rescan the token stream up to the error token to find the 10 tokens
//       // before the out of order ErrorToken.
//       Token errorToken = token;
//       Token start = firstToken;
//       int count = 0;
//       token = firstToken;
//       while (token != errorToken) {
//         token = token.next;
//         if (count < 10) {
//           ++count;
//         } else {
//           start = start.next;
//         }
//       }
//
//       // Print the out of order error token plus some tokens before and after.
//       count = 0;
//       token = start;
//       while (count < 20 && !token.isEof) {
//         print("${token.charOffset}: $token");
//         token = token.next;
//         ++count;
//       }
//       throw 'Out of order ErrorToken: $errorToken';
//     }
//     token = token.next;
//   }
// }
//
// mainEntryPoint(List<String> arguments) {
//   Map<Uri, List<int>> files = <Uri, List<int>>{};
//   Stopwatch sw = new Stopwatch()..start();
//   bool verbose = const bool.fromEnvironment("printTokens");
//   bool verify = const bool.fromEnvironment('verifyErrorTokens');
//   for (String arg in arguments) {
//     if (arg.startsWith('--')) {
//       if (arg == '--print-tokens') {
//         verbose = true;
//       } else if (arg == '--verify-error-tokens') {
//         verify = true;
//       } else {
//         print('Unrecognized option: $arg');
//       }
//       continue;
//     }
//
//     Uri uri = Uri.base.resolve(arg);
//     List<int> bytes = readBytesFromFileSync(uri);
//     files[uri] = bytes;
//   }
//   sw.stop();
//   print("Reading files took: ${sw.elapsed}");
//   scanAll(files, verbose: verbose, verify: verify);
// }
// Copyright (c) 2016, the Dart project authors.  Please see the AUTHORS file
// for details. All rights reserved. Use of this source code is governed by a
// BSD-style license that can be found in the LICENSE file.

class DebugListener extends Listener {
  void beginLiteralString(Token token) {
    print('beginLiteralString ${token.toString()}');
  }

  void endLiteralString(int interpolationCount, Token endToken) {
    print('endLiteralString ${endToken.toString()}');
  }

  void handleIdentifier(Token token, IdentifierContext context) {
    print('token ${token.toString()}');
    print('token next${token.next.toString()}');

    // logEvent("Identifier: ${token.lexeme} ${token.charOffset}");
  }

  // void logEvent(String name) {
  //   print('event $name');
  // }
}

Future<void> mainEntryPoint(List<String> arguments) async {
  for (String argument in arguments) {
    if (argument.startsWith("@")) {
      Uri uri = Uri.base.resolve(argument.substring(/* startIndex = */ 1));
      await for (String file in new File.fromUri(uri).openRead().cast<List<int>>().transform(utf8.decoder).transform(const LineSplitter())) {
        outLine(uri.resolve(file));
      }
    } else {
      outLine(Uri.base.resolve(argument));
    }
  }
}

void outLine(Uri uri) {
  Parser parser = Parser(new DebugListener());
  parser.parseUnit(scan(readBytesFromFileSync(uri)).tokens);
  // parser.rewriter.insertParens(token, false);
}

==> report-0.0.6.tar.gz: tool/backup/main.dart <==
// Copyright (c) 2016, the Dart project authors. Please see the AUTHORS file
// for details. All rights reserved. Use of this source code is governed by a
// BSD-style license that can be found in the LICENSE.md file.

import 'dart:convert';

import 'package:_fe_analyzer_shared/src/scanner/token.dart';
import 'package:_fe_analyzer_shared/src/scanner/io.dart' show readBytesFromFileSync;
// import 'package:_fe_analyzer_shared/src/scanner/error_token.dart';
import 'package:_fe_analyzer_shared/src/scanner/scanner.dart';
import 'dart:convert' show LineSplitter, utf8;

import 'dart:io' show File;

import 'package:_fe_analyzer_shared/src/scanner/token.dart' show Token;

// import 'package:_fe_analyzer_shared/src/scanner/io.dart' show readBytesFromFileSync;

import 'package:_fe_analyzer_shared/src/scanner/scanner.dart' show scan;

import 'package:_fe_analyzer_shared/src/parser/listener.dart' show Listener;

import 'package:_fe_analyzer_shared/src/parser/parser.dart';

import 'package:_fe_analyzer_shared/src/parser/identifier_context.dart' show IdentifierContext;

void main() {
  List<int> bytes = utf8.encode('class A { }').toList();
  bytes.add(0);
  mainEntryPoint(['/Users/dansun/Documents/github/report/package/bloc/test1/lib/test1.dart']);
  // scanAll({Uri.directory('/Users/dansun/Documents/github/report/tool'): bytes});
}

// scanAll(Map<Uri, List<int>> files, {bool verbose: true, bool verify: true}) {
//   Stopwatch sw = new Stopwatch()..start();
//   int byteCount = 0;
//   files.forEach((Uri uri, List<int> bytes) {
//     Token token = scan(bytes).tokens;
//     if (verbose) printTokens(token);
//     if (verify) verifyErrorTokens(token, uri);
//     byteCount += bytes.length - 1;
//   });
//   sw.stop();
//   print("Scanning files took: ${sw.elapsed}");
//   print("Bytes/ms: ${byteCount / sw.elapsedMilliseconds}");
// }
//
// void printTokens(Token token) {
//   while (!token.isEof) {
//     print("${token.charOffset}: $token");
//     token = token.next;
//   }
// }
//
// /// Verify that the fasta scanner recovery has moved all of the ErrorTokens
// /// to the beginning of the stream. If an out-of-order ErrorToken is
// /// found, then print some diagnostic information and throw an exception.
// void verifyErrorTokens(Token firstToken, Uri uri) {
//   Token token = firstToken;
//   while (token is ErrorToken) {
//     token = token.next;
//   }
//
//   while (!token.isEof) {
//     if (token is ErrorToken) {
//       print('Found out-of-order ErrorTokens when scanning:\n  $uri');
//
//       // Rescan the token stream up to the error token to find the 10 tokens
//       // before the out of order ErrorToken.
//       Token errorToken = token;
//       Token start = firstToken;
//       int count = 0;
//       token = firstToken;
//       while (token != errorToken) {
//         token = token.next;
//         if (count < 10) {
//           ++count;
//         } else {
//           start = start.next;
//         }
//       }
//
//       // Print the out of order error token plus some tokens before and after.
//       count = 0;
//       token = start;
//       while (count < 20 && !token.isEof) {
//         print("${token.charOffset}: $token");
//         token = token.next;
//         ++count;
//       }
//       throw 'Out of order ErrorToken: $errorToken';
//     }
//     token = token.next;
//   }
// }
//
// mainEntryPoint(List<String> arguments) {
//   Map<Uri, List<int>> files = <Uri, List<int>>{};
//   Stopwatch sw = new Stopwatch()..start();
//   bool verbose = const bool.fromEnvironment("printTokens");
//   bool verify = const bool.fromEnvironment('verifyErrorTokens');
//   for (String arg in arguments) {
//     if (arg.startsWith('--')) {
//       if (arg == '--print-tokens') {
//         verbose = true;
//       } else if (arg == '--verify-error-tokens') {
//         verify = true;
//       } else {
//         print('Unrecognized option: $arg');
//       }
//       continue;
//     }
//
//     Uri uri = Uri.base.resolve(arg);
//     List<int> bytes = readBytesFromFileSync(uri);
//     files[uri] = bytes;
//   }
//   sw.stop();
//   print("Reading files took: ${sw.elapsed}");
//   scanAll(files, verbose: verbose, verify: verify);
// }
// Copyright (c) 2016, the Dart project authors.  Please see the AUTHORS file
// for details. All rights reserved. Use of this source code is governed by a
// BSD-style license that can be found in the LICENSE file.

class DebugListener extends Listener {
  void beginLiteralString(Token token) {
    print('beginLiteralString ${token.toString()}');
  }

  void endLiteralString(int interpolationCount, Token endToken) {
    print('endLiteralString ${endToken.toString()}');
  }

  void handleIdentifier(Token token, IdentifierContext context) {
    print('token ${token.toString()}');
    print('token next${token.next.toString()}');

    // logEvent("Identifier: ${token.lexeme} ${token.charOffset}");
  }

  // void logEvent(String name) {
  //   print('event $name');
  // }
}

Future<void> mainEntryPoint(List<String> arguments) async {
  for (String argument in arguments) {
    if (argument.startsWith("@")) {
      Uri uri = Uri.base.resolve(argument.substring(/* startIndex = */ 1));
      await for (String file in new File.fromUri(uri).openRead().cast<List<int>>().transform(utf8.decoder).transform(const LineSplitter())) {
        outLine(uri.resolve(file));
      }
    } else {
      outLine(Uri.base.resolve(argument));
    }
  }
}

void outLine(Uri uri) {
  Parser parser = Parser(new DebugListener());
  parser.parseUnit(scan(readBytesFromFileSync(uri)).tokens);
  // parser.rewriter.insertParens(token, false);
}
